@@ -5,6 +5,7 @@ from collections.abc import Iterable
 
 from boto3.session import Session
 
+from mypy_boto3_builder.package_data import Boto3StubsPackageData
 from mypy_boto3_builder.parsers.fake_service_package import parse_fake_service_package
 from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.master_package import MasterPackage
@@ -23,6 +24,8 @@ def parse_master_package(session: Session, service_names: Iterable[ServiceName])
     """
     result = MasterPackage(service_names=service_names)
     for service_name in result.service_names:
-        result.service_packages.append(parse_fake_service_package(session, service_name))
+        result.service_packages.append(
+            parse_fake_service_package(session, service_name, Boto3StubsPackageData)
+        )
 
     return result
