@@ -47,7 +47,7 @@ def blackify(content: str, file_path: Path) -> str:
         if not file_path.parent.exists():
             file_path.parent.mkdir(exist_ok=True, parents=True)
         file_path.write_text(content)
-        raise ValueError(f"Cannot parse {file_path}: {e}") from e
+        raise ValueError(f"Cannot parse {file_path.as_posix()}: {e}") from e
 
     return content
 
